@@ -1,9 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
-"""Tests for `oceandb_driver_interface` package."""
-
-from pytest import mark, raises
+from pytest import raises
 from oceandb_driver_interface.utils import parse_config
 
 
@@ -23,7 +18,8 @@ def test_oceandb_expcects_subclassed_plugin():
     with raises(TypeError):
         AbstractPlugin(plugin)
 
+
 def test_parse_config():
     config = parse_config('./tests/oceandb.ini')
     assert config['module'] == 'bigchaindb'
-    assert config['db.hostname'] == 'localhost'
\ No newline at end of file
+    assert config['db.hostname'] == 'localhost'
